@@ -12,7 +12,8 @@ module Fog
                  :openstack_endpoint_type,
                  :openstack_project_name, :openstack_project_id,
                  :openstack_project_domain, :openstack_user_domain, :openstack_domain_name,
-                 :openstack_project_domain_id, :openstack_user_domain_id, :openstack_domain_id
+                 :openstack_project_domain_id, :openstack_user_domain_id, :openstack_domain_id,
+                 :openstack_identity_prefix
 
       model_path 'fog/openstack/models/orchestration'
       model       :stack
@@ -50,6 +51,7 @@ module Fog
       request :show_resource_template
       request :show_stack_details
       request :update_stack
+      request :patch_stack
       request :validate_template
 
       module Reflectable
