@@ -13,7 +13,8 @@ module Fog
                  :openstack_endpoint_type,
                  :openstack_project_name, :openstack_project_id,
                  :openstack_project_domain, :openstack_user_domain, :openstack_domain_name,
-                 :openstack_project_domain_id, :openstack_user_domain_id, :openstack_domain_id
+                 :openstack_project_domain_id, :openstack_user_domain_id, :openstack_domain_id,
+                 :openstack_identity_prefix, :openstack_temp_url_key
 
       model_path 'fog/openstack/models/storage'
       model       :directory
