@@ -108,6 +108,7 @@ Watchers      | #{watchers}
            'Ash Wilson',
            'Benson Kalahar',
            'Brian Hartsock',
+           'bryanl',
            'Chris Luo',
            'Chris Roberts',
            'Christopher Oliver',
@@ -140,6 +141,8 @@ Watchers      | #{watchers}
            'Paul Thornthwaite',
            'Paulo Henrique Lopes Ribeiro',
            'Peter Souter',
+           'Phil Ross',
+           'Rich Daley',
            'Rodrigo Estebanez',
            'Rupak Ganguly',
            'Stepan G. Fedorov',
